@@ -86,6 +86,7 @@ from silx.gui.widgets.FormGridLayout import FormGridLayout
 from silx.math.histogram import Histogramnd
 from silx.gui.plot.items.roi import RectangleROI
 from silx.gui.plot.tools.roi import RegionOfInterestManager
+from silx.utils.deprecation import deprecated
 from silx.utils.enum import Enum as _Enum
 
 _logger = logging.getLogger(__name__)
@@ -233,6 +234,7 @@ class _AutoscaleModeComboBox(qt.QComboBox):
     DATA = {
         Colormap.MINMAX: ("Min/max", "Use the data min/max"),
         Colormap.STDDEV3: ("Mean±3std", "Use the data mean ± 3 × standard deviation"),
+        Colormap.PERCENTILE_1_99: ("Percentile 1-99", "Use 1st to 99th percentile of data"),
     }
 
     def __init__(self, parent: qt.QWidget):
@@ -762,7 +764,7 @@ class _ColormapHistogram(qt.QWidget):
         return x, y
 
     def setDisplayMode(self, mode: str | DisplayMode):
-        mode = DisplayMode.from_value(mode)
+        mode = DisplayMode(mode)
         if mode is DisplayMode.HISTOGRAM:
             action = self._dataHistogramAction
         elif mode is DisplayMode.RANGE:
@@ -778,9 +780,13 @@ class _ColormapHistogram(qt.QWidget):
         self._displayMode = mode
         self._updateDisplayMode()
 
-    def getDsiplayMode(self) -> DisplayMode:
+    def getDisplayMode(self) -> DisplayMode:
         return self._displayMode
 
+    @deprecated(since_version="2.1.0", replacement="getDisplayMode")
+    def getDsiplayMode(self):
+        return self.getDisplayMode()
+
     def _displayModeChanged(self, action):
         mode = action.data()
         self._setDisplayMode(mode)
