@@ -36,8 +36,6 @@ from silx.gui.hdf5.Hdf5Formatter import Hdf5Formatter
 import silx.io
 from .AbstractDataFileDialog import AbstractDataFileDialog
 
-import fabio
-
 
 _logger = logging.getLogger(__name__)
 
@@ -336,4 +334,4 @@ class DataFileDialog(AbstractDataFileDialog):
             selection widget (basically the data from the browsing widget)
         :rtype: bool
         """
-        return u""
+        return ""
