@@ -1,6 +1,6 @@
 # /*##########################################################################
 #
-# Copyright (c) 2018-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2018-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -37,14 +37,14 @@ __date__ = "28/06/2018"
 import logging
 import numpy
 import weakref
+import functools
+from typing import Optional
 
 from ....utils.weakref import WeakList
 from ... import qt
 from .. import items
 from ..items import core
 from ...colors import rgba
-import silx.utils.deprecation
-from ....utils.proxy import docstring
 
 
 logger = logging.getLogger(__name__)
@@ -68,8 +68,10 @@ class _RegionOfInterestBase(qt.QObject):
     """
 
     def __init__(self, parent=None):
-        qt.QObject.__init__(self, parent=parent)
-        self.__name = ''
+        qt.QObject.__init__(self)
+        if parent is not None:
+            self.setParent(parent)
+        self.__name = ""
 
     def getName(self):
         """Returns the name of the ROI
@@ -120,10 +122,12 @@ class RoiInteractionMode(object):
 
     @property
     def label(self):
+        """Short name"""
         return self._label
 
     @property
     def description(self):
+        """Longer description of the interaction mode"""
         return self._description
 
 
@@ -188,6 +192,28 @@ class InteractionModeMixIn(object):
         """
         return self.__modeId
 
+    def createMenuForInteractionMode(self, parent: qt.QWidget) -> qt.QMenu:
+        """Create a menu providing access to the different interaction modes"""
+        availableModes = self.availableInteractionModes()
+        currentMode = self.getInteractionMode()
+        submenu = qt.QMenu(parent)
+        modeGroup = qt.QActionGroup(parent)
+        modeGroup.setExclusive(True)
+        for mode in availableModes:
+            action = qt.QAction(parent)
+            action.setText(mode.label)
+            action.setToolTip(mode.description)
+            action.setCheckable(True)
+            if mode is currentMode:
+                action.setChecked(True)
+            else:
+                callback = functools.partial(self.setInteractionMode, mode)
+                action.triggered.connect(callback)
+            modeGroup.addAction(action)
+            submenu.addAction(action)
+        submenu.setTitle("Interaction mode")
+        return submenu
+
 
 class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
     """Object describing a region of interest in a plot.
@@ -196,10 +222,10 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
         The RegionOfInterestManager that created this object
     """
 
-    _DEFAULT_LINEWIDTH = 1.
+    _DEFAULT_LINEWIDTH = 1.0
     """Default line width of the curve"""
 
-    _DEFAULT_LINESTYLE = '-'
+    _DEFAULT_LINESTYLE = "-"
     """Default line style of the curve"""
 
     _DEFAULT_HIGHLIGHT_STYLE = items.CurveStyle(linewidth=2)
@@ -225,15 +251,18 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
     def __init__(self, parent=None):
         # Avoid circular dependency
         from ..tools import roi as roi_tools
+
         assert parent is None or isinstance(parent, roi_tools.RegionOfInterestManager)
+        # Must be done before _RegionOfInterestBase.__init__
+        self._child = WeakList()
         _RegionOfInterestBase.__init__(self, parent)
         core.HighlightedMixIn.__init__(self)
-        self._color = rgba('red')
+        self.__text = None
+        self._color = rgba("red")
         self._editable = False
         self._selectable = False
         self._focusProxy = None
         self._visible = True
-        self._child = WeakList()
 
     def _connectToPlot(self, plot):
         """Called after connection to a plot"""
@@ -263,8 +292,11 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
         """
         # Avoid circular dependency
         from ..tools import roi as roi_tools
-        if (parent is not None and not isinstance(parent, roi_tools.RegionOfInterestManager)):
-            raise ValueError('Unsupported parent')
+
+        if parent is not None and not isinstance(
+            parent, roi_tools.RegionOfInterestManager
+        ):
+            raise ValueError("Unsupported parent")
 
         previousParent = self.parent()
         if previousParent is not None:
@@ -292,7 +324,7 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
         """
         assert item is not None
         self._child.append(item)
-        if item.getName() == '':
+        if item.getName() == "":
             self._setItemName(item)
         manager = self.parent()
         if manager is not None:
@@ -352,26 +384,6 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
             self._color = color
             self._updated(items.ItemChangedType.COLOR)
 
-    @silx.utils.deprecation.deprecated(reason='API modification',
-                                       replacement='getName()',
-                                       since_version=0.12)
-    def getLabel(self):
-        """Returns the label displayed for this ROI.
-
-        :rtype: str
-        """
-        return self.getName()
-
-    @silx.utils.deprecation.deprecated(reason='API modification',
-                                       replacement='setName(name)',
-                                       since_version=0.12)
-    def setLabel(self, label):
-        """Set the label displayed with this ROI.
-
-        :param str label: The text label to display
-        """
-        self.setName(name=label)
-
     def isEditable(self):
         """Returns whether the ROI is editable by the user or not.
 
@@ -457,6 +469,26 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
             self._visible = visible
             self._updated(items.ItemChangedType.VISIBLE)
 
+    def getText(self) -> str:
+        """Returns the currently displayed text for this ROI"""
+        return self.getName() if self.__text is None else self.__text
+
+    def setText(self, text: Optional[str] = None) -> None:
+        """Set the displayed text for this ROI.
+
+        If None (the default), the ROI name is used.
+        """
+        if self.__text != text:
+            self.__text = text
+            self._updated(items.ItemChangedType.TEXT)
+
+    def _updateText(self, text: str) -> None:
+        """Update the text displayed by this ROI
+
+        Override in subclass to custom text display
+        """
+        pass
+
     @classmethod
     def showFirstInteractionShape(cls):
         """Returns True if the shape created by the first interaction and
@@ -478,7 +510,7 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
         return cls._plotShape
 
     def setFirstShapePoints(self, points):
-        """"Initialize the ROI using the points from the first interaction.
+        """Initialize the ROI using the points from the first interaction.
 
         This interaction is constrained by the plot API and only supports few
         shapes.
@@ -486,13 +518,11 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
         raise NotImplementedError()
 
     def creationStarted(self):
-        """"Called when the ROI creation interaction was started.
-        """
+        """Called when the ROI creation interaction was started."""
         pass
 
     def creationFinalized(self):
-        """"Called when the ROI creation interaction was finalized.
-        """
+        """Called when the ROI creation interaction was finalized."""
         pass
 
     def _updateItemProperty(self, event, source, destination):
@@ -544,15 +574,23 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
             assert False
 
     def _updated(self, event=None, checkVisibility=True):
-        if event == items.ItemChangedType.HIGHLIGHTED:
+        if event == items.ItemChangedType.TEXT:
+            self._updateText(self.getText())
+        elif event == items.ItemChangedType.HIGHLIGHTED:
+            for item in self.getItems():
+                zoffset = 1000 if self.isHighlighted() else 0
+                item.setZValue(item._DEFAULT_Z_LAYER + zoffset)
+
             style = self.getCurrentStyle()
             self._updatedStyle(event, style)
         else:
-            styleEvents = [items.ItemChangedType.COLOR,
-                           items.ItemChangedType.LINE_STYLE,
-                           items.ItemChangedType.LINE_WIDTH,
-                           items.ItemChangedType.SYMBOL,
-                           items.ItemChangedType.SYMBOL_SIZE]
+            styleEvents = [
+                items.ItemChangedType.COLOR,
+                items.ItemChangedType.LINE_STYLE,
+                items.ItemChangedType.LINE_WIDTH,
+                items.ItemChangedType.SYMBOL,
+                items.ItemChangedType.SYMBOL_SIZE,
+            ]
             if self.isHighlighted():
                 styleEvents.append(items.ItemChangedType.HIGHLIGHTED_STYLE)
 
@@ -562,7 +600,11 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
 
         super(RegionOfInterest, self)._updated(event, checkVisibility)
 
-    def _updatedStyle(self, event, style):
+        # Displayed text has changed, send a text event
+        if event == items.ItemChangedType.NAME and self.__text is None:
+            self._updated(items.ItemChangedType.TEXT, checkVisibility)
+
+    def _updatedStyle(self, event, style: items.CurveStyle):
         """Called when the current displayed style of the ROI was changed.
 
         :param event: The event responsible of the change of the style
@@ -570,7 +612,7 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
         """
         pass
 
-    def getCurrentStyle(self):
+    def getCurrentStyle(self) -> items.CurveStyle:
         """Returns the current curve style.
 
         Curve style depends on curve highlighting
@@ -588,7 +630,7 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
             baseSymbol = self.getSymbol()
             baseSymbolsize = self.getSymbolSize()
         else:
-            baseSymbol = 'o'
+            baseSymbol = "o"
             baseSymbolsize = 1
 
         if self.isHighlighted():
@@ -604,13 +646,16 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
                 linestyle=baseLinestyle if linestyle is None else linestyle,
                 linewidth=baseLinewidth if linewidth is None else linewidth,
                 symbol=baseSymbol if symbol is None else symbol,
-                symbolsize=baseSymbolsize if symbolsize is None else symbolsize)
+                symbolsize=baseSymbolsize if symbolsize is None else symbolsize,
+            )
         else:
-            return items.CurveStyle(color=baseColor,
-                                    linestyle=baseLinestyle,
-                                    linewidth=baseLinewidth,
-                                    symbol=baseSymbol,
-                                    symbolsize=baseSymbolsize)
+            return items.CurveStyle(
+                color=baseColor,
+                linestyle=baseLinestyle,
+                linewidth=baseLinewidth,
+                symbol=baseSymbol,
+                symbolsize=baseSymbolsize,
+            )
 
     def _editingStarted(self):
         assert self._editable is True
@@ -619,6 +664,10 @@ class RegionOfInterest(_RegionOfInterestBase, core.HighlightedMixIn):
     def _editingFinished(self):
         self.sigEditingFinished.emit()
 
+    def populateContextMenu(self, menu: qt.QMenu):
+        """Populate a menu used as a context menu"""
+        pass
+
 
 class HandleBasedROI(RegionOfInterest):
     """Manage a ROI based on a set of handles"""
@@ -730,9 +779,7 @@ class HandleBasedROI(RegionOfInterest):
 
         See :class:`~silx.gui.plot.items.Item._updated`
         """
-        if event == items.ItemChangedType.NAME:
-            self._updateText(self.getName())
-        elif event == items.ItemChangedType.VISIBLE:
+        if event == items.ItemChangedType.VISIBLE:
             for item, role in self._handles:
                 visible = self.isVisible()
                 editionVisible = visible and self.isEditable()
@@ -754,9 +801,9 @@ class HandleBasedROI(RegionOfInterest):
         color = rgba(self.getColor())
         handleColor = self._computeHandleColor(color)
         for item, role in self._handles:
-            if role == 'user':
+            if role == "user":
                 pass
-            elif role == 'label':
+            elif role == "label":
                 item.setColor(color)
             else:
                 item.setColor(handleColor)
@@ -825,10 +872,3 @@ class HandleBasedROI(RegionOfInterest):
         :rtype: Union[numpy.array,Tuple,List]
         """
         return color[:3] + (0.5,)
-
-    def _updateText(self, text):
-        """Update the text displayed by this ROI
-
-        :param str text: A text
-        """
-        pass
