@@ -1,4 +1,4 @@
-# /*##########################################################################
+# /*#########################################################################
 #
 # Copyright (c) 2017-2023 European Synchrotron Radiation Facility
 #
@@ -20,7 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 #
-# ###########################################################################*/
+# ##########################################################################*/
 """This module provides the :class:`ImageData` and :class:`ImageRgba` items
 of the :class:`Plot`.
 """
@@ -595,8 +595,9 @@ class MaskImageData(ImageData):
 
     pass
 
+from .image_aggregated import ImageDataAggregated
 
-class ImageStack(ImageData):
+class ImageStack(ImageDataAggregated):
     """Item to store a stack of images and to show it in the plot as one
     of the images of the stack.
 
@@ -605,7 +606,7 @@ class ImageStack(ImageData):
     """
 
     def __init__(self):
-        ImageData.__init__(self)
+        ImageDataAggregated.__init__(self)
         self.__stack = None
         """A 3D numpy array (or a mimic one, see ListOfImages)"""
         self.__stackPosition = None
