@@ -78,11 +78,19 @@ class MarkerBase(Item, DraggableMixIn, ColorMixIn, YAxisMixIn):
 
         self._x = None
         self._y = None
+        self._symbol_size = 10.0
         self._bgColor: colors.RGBAColorType | None = None
         self._constraint = self._defaultConstraint
         self.__isBeingDragged = False
 
-    def _addRendererCall(self, backend, symbol=None, linestyle="-", linewidth=1):
+    def _addRendererCall(
+        self,
+        backend,
+        symbol=None,
+        symbolsize=10.,
+        linestyle="-",
+        linewidth=1,
+    ):
         """Perform the update of the backend renderer"""
         return backend.addMarker(
             x=self.getXPosition(),
@@ -90,6 +98,7 @@ class MarkerBase(Item, DraggableMixIn, ColorMixIn, YAxisMixIn):
             text=self.getText(),
             color=self.getColor(),
             symbol=symbol,
+            symbolsize=symbolsize,
             linestyle=linestyle,
             linewidth=linewidth,
             constraint=self.getConstraint(),
@@ -246,6 +255,9 @@ class Marker(MarkerBase, SymbolMixIn):
     _DEFAULT_SYMBOL = "+"
     """Default symbol of the marker"""
 
+    _DEFAULT_SYMBOL_SIZE = 10.0
+    """Default size of marker's symbol"""
+
     def __init__(self):
         MarkerBase.__init__(self)
         SymbolMixIn.__init__(self)
@@ -254,7 +266,11 @@ class Marker(MarkerBase, SymbolMixIn):
         self._y = 0.0
 
     def _addBackendRenderer(self, backend):
-        return self._addRendererCall(backend, symbol=self.getSymbol())
+        return self._addRendererCall(
+            backend,
+            symbol=self.getSymbol(),
+            symbolsize=self.getSymbolSize(),
+        )
 
     def _setConstraint(self, constraint):
         """Set the constraint function of the marker drag.
