@@ -27,8 +27,6 @@ __authors__ = ["T. Vincent"]
 __license__ = "MIT"
 __date__ = "06/03/2018"
 
-import unittest
-
 from silx.gui.widgets.BoxLayoutDockWidget import BoxLayoutDockWidget
 from silx.gui import qt
 from silx.gui.utils.testutils import TestCaseQt
@@ -53,8 +51,8 @@ class TestBoxLayoutDockWidget(TestCaseQt):
         """Test update of layout direction according to dock area"""
         # Create a widget with a QBoxLayout
         layout = qt.QBoxLayout(qt.QBoxLayout.LeftToRight)
-        layout.addWidget(qt.QLabel('First'))
-        layout.addWidget(qt.QLabel('Second'))
+        layout.addWidget(qt.QLabel("First"))
+        layout.addWidget(qt.QLabel("Second"))
         widget = qt.QWidget()
         widget.setLayout(layout)
 
