@@ -1,6 +1,6 @@
 # /*##########################################################################
 #
-# Copyright (c) 2017-2021 European Synchrotron Radiation Facility
+# Copyright (c) 2017-2023 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -29,7 +29,6 @@ import logging
 import numpy
 
 from silx.io import is_dataset
-from silx.utils.deprecation import deprecated
 
 
 __authors__ = ["P. Knobel"]
@@ -40,21 +39,18 @@ __date__ = "17/04/2018"
 nxdata_logger = logging.getLogger("silx.io.nxdata")
 
 
-INTERPDIM = {"scalar": 0,
-             "spectrum": 1,
-             "image": 2,
-             "rgba-image": 3,  # "hsla-image": 3, "cmyk-image": 3, # TODO
-             "vertex": 1}  # 3D scatter: 1D signal + 3 axes (x, y, z) of same legth
+INTERPDIM = {
+    "scalar": 0,
+    "spectrum": 1,
+    "image": 2,
+    "rgba-image": 3,  # "hsla-image": 3, "cmyk-image": 3, # TODO
+    "vertex": 1,
+}  # 3D scatter: 1D signal + 3 axes (x, y, z) of same legth
 """Number of signal dimensions associated to each possible @interpretation
 attribute.
 """
 
 
-@deprecated(since_version="0.8.0", replacement="get_attr_as_unicode")
-def get_attr_as_string(*args, **kwargs):
-    return get_attr_as_unicode(*args, **kwargs)
-
-
 def get_attr_as_unicode(item, attr_name, default=None):
     """Return item.attrs[attr_name] as unicode or as a
     list of unicode.
@@ -107,13 +103,16 @@ def get_signal_name(group):
     """
     signal_name = get_attr_as_unicode(group, "signal", default=None)
     if signal_name is None:
-        nxdata_logger.info("NXdata group %s does not define a signal attr. "
-                           "Testing legacy specification.", group.name)
+        nxdata_logger.info(
+            "NXdata group %s does not define a signal attr. "
+            "Testing legacy specification.",
+            group.name,
+        )
         for key in group:
             if "signal" in group[key].attrs:
                 signal_name = key
                 signal_attr = group[key].attrs["signal"]
-                if signal_attr in [1, b"1", u"1"]:
+                if signal_attr in [1, b"1", "1"]:
                     # This is the main (default) signal
                     break
     return signal_name
@@ -121,8 +120,9 @@ def get_signal_name(group):
 
 def get_auxiliary_signals_names(group):
     """Return list of auxiliary signals names"""
-    auxiliary_signals_names = get_attr_as_unicode(group, "auxiliary_signals",
-                                                  default=[])
+    auxiliary_signals_names = get_attr_as_unicode(
+        group, "auxiliary_signals", default=[]
+    )
     if isinstance(auxiliary_signals_names, (str, bytes)):
         auxiliary_signals_names = [auxiliary_signals_names]
     return auxiliary_signals_names
@@ -133,11 +133,12 @@ def validate_auxiliary_signals(group, signal_name, auxiliary_signals_names):
     issues = []
     for asn in auxiliary_signals_names:
         if asn not in group or not is_dataset(group[asn]):
-            issues.append(
-                "Cannot find auxiliary signal dataset '%s'" % asn)
+            issues.append("Cannot find auxiliary signal dataset '%s'" % asn)
         elif group[signal_name].shape != group[asn].shape:
-            issues.append("Auxiliary signal dataset '%s' does not" % asn +
-                           " have the same shape as the main signal.")
+            issues.append(
+                "Auxiliary signal dataset '%s' does not" % asn
+                + " have the same shape as the main signal."
+            )
     return issues
 
 
@@ -147,9 +148,10 @@ def validate_number_of_axes(group, signal_name, num_axes):
     if 1 < ndims < num_axes:
         # ndim = 1 with several axes could be a scatter
         issues.append(
-            "More @axes defined than there are " +
-            "signal dimensions: " +
-            "%d axes, %d dimensions." % (num_axes, ndims))
+            "More @axes defined than there are "
+            + "signal dimensions: "
+            + "%d axes, %d dimensions." % (num_axes, ndims)
+        )
 
     # case of less axes than dimensions: number of axes must match
     # dimensionality defined by @interpretation
@@ -158,25 +160,30 @@ def validate_number_of_axes(group, signal_name, num_axes):
         if interpretation is None:
             interpretation = get_attr_as_unicode(group, "interpretation")
         if interpretation is None:
-            issues.append("No @interpretation and not enough" +
-                          " @axes defined.")
+            issues.append("No @interpretation and not enough" + " @axes defined.")
 
         elif interpretation not in INTERPDIM:
-            issues.append("Unrecognized @interpretation=" + interpretation +
-                          " for data with wrong number of defined @axes.")
+            issues.append(
+                "Unrecognized @interpretation="
+                + interpretation
+                + " for data with wrong number of defined @axes."
+            )
         elif interpretation == "rgba-image":
             if ndims != 3 or group[signal_name].shape[-1] not in [3, 4]:
                 issues.append(
-                    "Inconsistent RGBA Image. Expected 3 dimensions with " +
-                    "last one of length 3 or 4. Got ndim=%d " % ndims +
-                    "with last dimension of length %d." % group[signal_name].shape[-1])
+                    "Inconsistent RGBA Image. Expected 3 dimensions with "
+                    + "last one of length 3 or 4. Got ndim=%d " % ndims
+                    + "with last dimension of length %d." % group[signal_name].shape[-1]
+                )
             if num_axes != 2:
                 issues.append(
                     "Inconsistent number of axes for RGBA Image. Expected "
-                    "3, but got %d." % ndims)
+                    "3, but got %d." % ndims
+                )
 
         elif num_axes != INTERPDIM[interpretation]:
             issues.append(
-                "%d-D signal with @interpretation=%s " % (ndims, interpretation) +
-                "must define %d or %d axes." % (ndims, INTERPDIM[interpretation]))
+                "%d-D signal with @interpretation=%s " % (ndims, interpretation)
+                + "must define %d or %d axes." % (ndims, INTERPDIM[interpretation])
+            )
     return issues
