@@ -27,9 +27,7 @@ __date__ = "22/06/2016"
 
 
 from .leastsq import leastsq, chisq_alpha_beta
-from .leastsq import \
-    CFREE, CPOSITIVE, CQUOTED, CFIXED, \
-    CFACTOR, CDELTA, CSUM
+from .leastsq import CFREE, CPOSITIVE, CQUOTED, CFIXED, CFACTOR, CDELTA, CSUM
 
 from .functions import *
 from .filters import *
