@@ -385,6 +385,8 @@ class Convolution(OpenclProcessing):
             self.kernel_args, input_ref, output_ref
         )
         ev = opencl_kernel(*opencl_kernel_args)
+        if self.queue.device.type == cl.device_type.CPU:
+            ev.wait()
         if self.profile:
             self.events.append(EventDescription("batched convolution", ev))
 
