@@ -46,9 +46,12 @@ _logger = logging.getLogger(__name__)
 
 
 if sys.hexversion >= 0x030400F0:  # Python >= 3.4
+
     class ParametricTestCase(unittest.TestCase):
         pass
+
 else:
+
     class ParametricTestCase(unittest.TestCase):
         """TestCase with subTest support for Python < 3.4.
 
@@ -63,8 +66,8 @@ else:
         def subTest(self, msg=None, **params):
             """Use as unittest.TestCase.subTest method in Python >= 3.4."""
             # Format arguments as: '[msg] (key=value, ...)'
-            param_str = ', '.join(['%s=%s' % (k, v) for k, v in params.items()])
-            self._subtest_msg = '[%s] (%s)' % (msg or '', param_str)
+            param_str = ", ".join(["%s=%s" % (k, v) for k, v in params.items()])
+            self._subtest_msg = "[%s] (%s)" % (msg or "", param_str)
             yield
             self._subtest_msg = None
 
@@ -72,8 +75,9 @@ else:
             short_desc = super(ParametricTestCase, self).shortDescription()
             if self._subtest_msg is not None:
                 # Append subTest message to shortDescription
-                short_desc = ' '.join(
-                    [msg for msg in (short_desc, self._subtest_msg) if msg])
+                short_desc = " ".join(
+                    [msg for msg in (short_desc, self._subtest_msg) if msg]
+                )
 
             return short_desc if short_desc else None
 
@@ -143,8 +147,16 @@ class LoggingValidator(logging.Handler):
     :raises RuntimeError: If the message counts are the expected ones.
     """
 
-    def __init__(self, logger=None, critical=None, error=None,
-                 warning=None, info=None, debug=None, notset=None):
+    def __init__(
+        self,
+        logger=None,
+        critical=None,
+        error=None,
+        warning=None,
+        info=None,
+        debug=None,
+        notset=None,
+    ):
         if logger is None:
             logger = logging.getLogger()
         elif not isinstance(logger, logging.Logger):
@@ -159,10 +171,12 @@ class LoggingValidator(logging.Handler):
             logging.WARNING: warning,
             logging.INFO: info,
             logging.DEBUG: debug,
-            logging.NOTSET: notset
+            logging.NOTSET: notset,
         }
 
-        self._expected_count = sum([v for k, v in self.expected_count_by_level.items() if v is not None])
+        self._expected_count = sum(
+            [v for k, v in self.expected_count_by_level.items() if v is not None]
+        )
         """Amount of any logging expected"""
 
         super(LoggingValidator, self).__init__()
@@ -189,15 +203,14 @@ class LoggingValidator(logging.Handler):
         return len(self.records) >= self._expected_count
 
     def get_count_by_level(self):
-        """Returns the current message count by level.
-        """
+        """Returns the current message count by level."""
         count = {
             logging.CRITICAL: 0,
             logging.ERROR: 0,
             logging.WARNING: 0,
             logging.INFO: 0,
             logging.DEBUG: 0,
-            logging.NOTSET: 0
+            logging.NOTSET: 0,
         }
         for record in self.records:
             level = record.levelno
@@ -230,18 +243,30 @@ class LoggingValidator(logging.Handler):
                     message += ", "
                 count = count_by_level[level]
                 expected_count = expected_count_by_level[level]
-                message += "%d %s (got %d)" % (expected_count, logging.getLevelName(level), count)
+                message += "%d %s (got %d)" % (
+                    expected_count,
+                    logging.getLevelName(level),
+                    count,
+                )
 
             raise LoggingRuntimeError(
-                'Expected %s' % message, records=list(self.records))
+                "Expected %s" % message, records=list(self.records)
+            )
 
     def emit(self, record):
         """Override :meth:`logging.Handler.emit`"""
         self.records.append(record)
 
 
-def validate_logging(logger=None, critical=None, error=None,
-                     warning=None, info=None, debug=None, notset=None):
+def validate_logging(
+    logger=None,
+    critical=None,
+    error=None,
+    warning=None,
+    info=None,
+    debug=None,
+    notset=None,
+):
     """Decorator checking number of logging messages.
 
     Propagation of logging messages is disabled by this decorator.
@@ -270,16 +295,20 @@ def validate_logging(logger=None, critical=None, error=None,
     :param int notset: Expected number of NOTSET messages.
                        Default: Do not check.
     """
+
     def decorator(func):
         test_context = LoggingValidator(
-            logger, critical, error, warning, info, debug, notset)
+            logger, critical, error, warning, info, debug, notset
+        )
 
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             with test_context:
                 result = func(*args, **kwargs)
             return result
+
         return wrapper
+
     return decorator
 
 
@@ -290,7 +319,8 @@ class TestLogging(LoggingValidator):
             "Class",
             "TestLogging",
             since_version="1.0.0",
-            replacement="LoggingValidator")
+            replacement="LoggingValidator",
+        )
         super().__init__(*args, **kwargs)
 
 
@@ -325,6 +355,7 @@ class EnsureImportError(object):
         if it is already imported. It only ensures that any attempt to import
         it again will cause an ImportError to be raised.
     """
+
     def __init__(self, name):
         """
 
